@@ -1,6 +1,7 @@
 /*
  *   Copyright (C) 2007 Tobias Koenig <tokoe@kde.org>
  *   Copyright  2008 by Anne-Marie Mahfouf <annma@kde.org>
+ *   Copyright 2016 Weng Xuetian <wengxt@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,11 +24,9 @@
 #include <QtCore/QRegExp>
 #include <QtGui/QImage>
 
-#include <KDebug>
+#include <QDebug>
 #include <kio/job.h>
 
-POTDPROVIDER_EXPORT_PLUGIN( WcpotdProvider, "WcpotdProvider", "" )
-
 class WcpotdProvider::Private
 {
   public:
@@ -52,7 +51,7 @@ void WcpotdProvider::Private::pageRequestFinished( KJob *_job )
 	return;
     }
 
-    KUrl picUrl( QLatin1String( "http://tools.wikimedia.de/~daniel/potd/potd.php/commons/800x600" ) );  KIO::StoredTransferJob *imageJob = KIO::storedGet( picUrl, KIO::NoReload, KIO::HideProgressInfo );
+    QUrl picUrl( QLatin1String( "https://tools.wmflabs.org/potd-feed/potd.php/commons/full" ) );  KIO::StoredTransferJob *imageJob = KIO::storedGet( picUrl, KIO::NoReload, KIO::HideProgressInfo );
     mParent->connect( imageJob, SIGNAL(finished(KJob*)), SLOT(imageRequestFinished(KJob*)) );
 }
 
@@ -71,7 +70,7 @@ void WcpotdProvider::Private::imageRequestFinished( KJob *_job )
 WcpotdProvider::WcpotdProvider( QObject *parent, const QVariantList &args )
     : PotdProvider( parent, args ), d( new Private( this ) )
 {
-    KUrl url( QLatin1String( "http://tools.wikimedia.de/~daniel/potd/potd.php/commons/800x600" ));
+    QUrl url( QLatin1String( "https://tools.wmflabs.org/potd-feed/potd.php/commons/full" ));
 
     KIO::StoredTransferJob *job = KIO::storedGet( url, KIO::NoReload, KIO::HideProgressInfo );
     connect( job, SIGNAL(finished(KJob*)), SLOT(pageRequestFinished(KJob*)) );
@@ -87,3 +86,7 @@ QImage WcpotdProvider::image() const
     return d->mImage;
 }
 
+K_PLUGIN_FACTORY_WITH_JSON(WcpotdProviderFactory, "wcpotdprovider.json", registerPlugin<WcpotdProvider>();)
+
+#include "wcpotdprovider.moc"
+#include "moc_wcpotdprovider.cpp"
